pub struct ChainedTokenExtractor { /* private fields */ }Expand description
Extract tokens from multiple sources
This struct tries multiple token extractors in sequence until one returns a token. It can be used to extract tokens from different headers or using different methods.
Implementations
Sourceimpl ChainedTokenExtractor
impl ChainedTokenExtractor
Sourcepub fn new(extractors: Vec<Arc<dyn TokenExtractor>>) -> Self
pub fn new(extractors: Vec<Arc<dyn TokenExtractor>>) -> Self
Sourcepub fn add_extractor(self, extractor: Arc<dyn TokenExtractor>) -> Self
pub fn add_extractor(self, extractor: Arc<dyn TokenExtractor>) -> Self