JwkProvider

Struct JwkProvider 

pub struct JwkProvider { /* private fields */ }
JWK provider for fetching and caching JWKs

Implementations

Source

impl JwkProvider

pub fn new( region: &str, user_pool_id: &str, cache_duration: Duration, ) -> Result<Self, JwtError>

Create a new JWK provider

This constructor creates a JwkProvider without prefetching keys. Keys will be fetched on the first request.

pub fn from_jwks_url( jwks_url: &str, issuer: &str, cache_duration: Duration, ) -> Result<Self, JwtError>

Create a new JWK provider from a JWKS URL (for OIDC providers)

This constructor creates a JwkProvider for generic OIDC providers. Keys will be fetched on the first request.

Arguments
  • jwks_url - The full URL to the JWKS endpoint (e.g., “https://example.com/.well-known/jwks.json”)
  • issuer - The issuer URL (e.g., “https://example.com”)
  • cache_duration - How long to cache keys before refreshing
pub fn get_issuer(&self) -> &str

Get the issuer URL

pub async fn prefetch_keys(&self) -> Result<(), JwtError>

Prefetch JWKs from the Cognito user pool This method should be called when the system starts to ensure JWKs are available

pub async fn get_key(&self, kid: &str) -> Result<DecodingKey, JwtError>

Get a JWK by key ID